==> hoteldruid-mod-pt_2.1.2-2.zip: pt/modifica_ospiti.php <==
<?php

switch ($messaggio) {

case "Modifica gli ospiti della prenotazione":	$messaggio = "Modificar hóspedes da reserva"; break;
case "Cliente titolare":  			$messaggio = "Cliente titular"; break;
case "Ospite della prenotazione":  		$messaggio = "Hóspede da reserva"; break;
case "nato il":  				$messaggio = "nascido a"; break;
case "nata il":  				$messaggio = "nascida a"; break;
case "CAP":  					$messaggio = "CEP"; break;
case "Telefono":  				$messaggio = "Telefone"; break;
case "2º telefono":  				$messaggio = "2º telefone"; break;
case "3º telefono":  				$messaggio = "3º telefone"; break;
case "Cognome":  				$messaggio = "Sobrenome"; break;
case "nome":  					$messaggio = "Nome"; break;
case "sesso":  					$messaggio = "Sexo"; break;
case "Data di nascita":  			$messaggio = "Data de nascimento"; break;
case "anno con 4 cifre":  			$messaggio = "ano com 4 dígitos"; break;
case "Documento":  				$messaggio = "Documento"; break;
case "scadenza":  				$messaggio = "validade"; break;
case "Altri ospiti":  				$messaggio = "Outros hóspedes"; break;
case "Modifica gli ospiti":  			$messaggio = "Modificar hóspedes"; break;
case "Torna indietro":  			$messaggio = "Voltar"; break;
case "Gli ospiti della prenotazione":  		$messaggio = "Os hóspedes da reserva"; break;
case "sono stati modificati":  			$messaggio = "foram modificados"; break;
case "nato":  					$messaggio = "nascido"; break;
case "nata":  					$messaggio = "nascida"; break;
case "il":  					$messaggio = "o"; break;
case " a":  					$messaggio = " em"; break;
case "scade":  					$messaggio = "expira"; break;
case "cittadinanza":  				$messaggio = "Nacionalidade"; break;
case "città di nascita":  			$messaggio = "Cidade de nascimento"; break;
case "reg./prov. di nascita":  			$messaggio = "Região de nascimento"; break;
case "nazione di nascita":  			$messaggio = "País de nascimento"; break;
case "reg./prov.":  				$messaggio = "região"; break;
case "nazione":  				$messaggio = "país"; break;
case "Nazione":  				$messaggio = "Nação"; break;
case "rilasciato da":  				$messaggio = "emitido por"; break;
case "nazione di rilascio":  			$messaggio = "país de emissão"; break;
case "Ospite principale":  			$messaggio = "Hóspede principal"; break;
case "Parentela":  				$messaggio = "Parentesco"; break;
case "parentela":  				$messaggio = "Parentesco"; break;
case "Codice fiscale":  			$messaggio = "Código fiscal"; break;
case "città":  					$messaggio = "cidade"; break;
case "Partita iva":  				$messaggio = "N° IVA"; break;
case "Modifica gli ospiti delle prenotazioni":	$messaggio = "Modifcar os hóspedes das reservas"; break;
case "della prenotazione":  			$messaggio = "da reserva"; break;
case "Gli ospiti delle prenotazioni":  		$messaggio = "Os hóspedes das reservas"; break;
case "ln.":  					$messaggio = "fala"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-pt_3.0.8-1.zip: pt/modifica_ospiti.php <==
<?php

switch ($messaggio) {

case "Modifica Ospiti":  			$messaggio = "Modificar hospede"; break;
case "Modifica gli ospiti della prenotazione":	$messaggio = "Modificar os hóspedes da reserva"; break;
case "Cliente titolare":  			$messaggio = "Cliente titular"; break;
case "Ospite della prenotazione":  		$messaggio = "Hóspede da reserva"; break;
case "nato il":  				$messaggio = "nascido a"; break;
case "nata il":  				$messaggio = "nascida a"; break;
case "CAP":  					$messaggio = "CEP"; break;
case "Telefono":  				$messaggio = "Telefone"; break;
case "2º telefono":  				$messaggio = "2º telefone"; break;
case "3º telefono":  				$messaggio = "3º telefone"; break;
case "Cognome":  				$messaggio = "Sobrenome"; break;
case "nome":  					$messaggio = "Nome"; break;
case "sesso":  					$messaggio = "Sexo"; break;
case "Data di nascita":  			$messaggio = "Data de nascimento"; break;
case "anno con 4 cifre":  			$messaggio = "ano com 4 números"; break;
case "Documento":  				$messaggio = "Documento"; break;
case "scadenza":  				$messaggio = "validade"; break;
case "Altri ospiti":  				$messaggio = "Outros hóspedes"; break;
case "Modifica gli ospiti":  			$messaggio = "Modificar hóspedes"; break;
case "Torna indietro":  			$messaggio = "Voltar"; break;
case "Gli ospiti della prenotazione":  		$messaggio = "Os hóspedes da reserva"; break;
case "sono stati modificati":  			$messaggio = "foram modificados"; break;
case "nato":  					$messaggio = "nascido"; break;
case "nata":  					$messaggio = "nascida"; break;
case "il":  					$messaggio = "o"; break;
case " a":  					$messaggio = " em"; break;
case "scade":  					$messaggio = "expira"; break;
case "cittadinanza":  				$messaggio = "Cidadania"; break;
case "città di nascita":  			$messaggio = "Cidade de nascimento"; break;
case "reg./prov. di nascita":  			$messaggio = "reg./prov. de nascimento"; break;
case "nazione di nascita":  			$messaggio = "País de nascimento"; break;
case "reg./prov.":  				$messaggio = "reg./prov."; break;
case "nazione":  				$messaggio = "país"; break;
case "Nazione":  				$messaggio = "País"; break;
case "rilasciato da":  				$messaggio = "emitido por"; break;
case "nazione di rilascio":  			$messaggio = "país da emissão"; break;
case "Ospite principale":  			$messaggio = "Hóspede principal"; break;
case "Parentela":  				$messaggio = "Parentesco"; break;
case "parentela":  				$messaggio = "parentesco"; break;
case "Codice fiscale":  			$messaggio = "Código fiscal"; break;
case "città":  					$messaggio = "cidade"; break;
case "Partita iva":  				$messaggio = "Nº IVA"; break;
case "Modifica gli ospiti delle prenotazioni":	$messaggio = "Modifcar os hóspedes das reservas"; break;
case "della prenotazione":  			$messaggio = "da reserva"; break;
case "Gli ospiti delle prenotazioni":  		$messaggio = "Os hóspedes das reservas"; break;
case "ln.":  					$messaggio = "lí."; break;
case "email":  					$messaggio = "e-mail"; break;
case "2ª email":  				$messaggio = "2º e-mail"; break;
case "PEC/codice":  				$messaggio = "PEC ou código de verificação"; break;
case "2° cognome":  				$messaggio = "2nd surname"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
